@@ -1,6 +1,6 @@
 package MusicBrainz::Queries;
 
-# $Id: Queries.pm,v 1.7 2004/06/17 22:42:22 sander Exp $
+# $Id: Queries.pm,v 1.8 2005/04/25 10:30:00 sander Exp $
 
 use 5.006_001; 
 use strict;
@@ -26,7 +26,6 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	MBE_AlbumGetAlbumStatus
 	MBE_AlbumGetAlbumType
 	MBE_AlbumGetAmazonAsin
-	MBE_AlbumGetAmazonCoverartURL
 	MBE_AlbumGetArtistId
 	MBE_AlbumGetArtistName
 	MBE_AlbumGetArtistSortName
@@ -121,7 +120,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = do { my @r = (q$Revision: 1.7 $ =~ /\d+/g); $r[0]--;sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker  
+our $VERSION = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); $r[0]--;sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker  
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -206,10 +205,6 @@ Return the release type of the currently selected Album.
 
 Return the Amazon.com ASIN for the currently selected Album.
 
-=item MBE_AlbumGetAmazonCoverartURL
-
-Return the Amazon.com URL for the cover art of the currently selected Album.
-
 =item MBE_AlbumGetArtistId
 
 Return the artist Id of the nth track in the album. Requires a 
@@ -695,7 +690,7 @@ Sander van Zoest, E<lt>svanzoest@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Alexander van Zoest
+Copyright 2003-2005 by Alexander van Zoest
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
